@@ -9,7 +9,7 @@ mainwindow::mainwindow(QWidget *parent) :
     QLocale::setDefault(QLocale(QLocale::English, QLocale::UnitedStates));
     this->setAttribute(Qt::WA_Maemo5StackedWindow);
     this->setWindowFlags(Qt::Window);
-    
+
     setAttribute(Qt::WA_Maemo5AutoOrientation, true);
 
     ui->setupUi(this);
@@ -34,7 +34,7 @@ mainwindow::mainwindow(QWidget *parent) :
     orientationChanged();
     readvalues();
     abouttext = tr("Author: d-iivil<br />Licence: GPL");
-    abouttitle = "CSSU Transitions Tuner " + tr("version") + " 0.1.6";
+    abouttitle = "CSSU Tuner " + tr("version") + " 0.1.7";
 }
 
 mainwindow::~mainwindow()
@@ -56,6 +56,19 @@ void mainwindow::orientationChanged()
 
 }
 
+void mainwindow::sed(QString speed, QString path)
+{
+    QProcess proc;
+    proc.start("perl -pi -e \"s/duration=.*/duration=" + speed + "/g\" " + path);
+    proc.waitForFinished();
+
+    proc.start("perl -pi -e \"s/duration_in=.*/duration_in=" + speed + "/g\" " + path);
+    proc.waitForFinished();
+
+    proc.start("perl -pi -e \"s/duration_out=.*/duration_out=" + speed + "/g\" " + path);
+    proc.waitForFinished();
+}
+
 void mainwindow::readvalues()
 {
     QString path;
@@ -66,6 +79,58 @@ void mainwindow::readvalues()
         path = "/usr/share/hildon-desktop/transitions.ini";
     }
 
+    QProcess proc;
+
+    proc.start("gconftool-2 -g /apps/osso/maemo-statusmenu-fmtx/always_visible");
+    proc.waitForReadyRead();
+    QString fm = proc.readLine();
+    fm.remove(" ");
+    if (fm == "false\n") {
+        ui->fm->setChecked(false);
+    } else {
+       ui->fm->setChecked(true);
+    }
+    proc.waitForFinished();
+
+    proc.start("gconftool-2 -g /apps/osso/hildon-desktop/menu_edit_disabled");
+    proc.waitForReadyRead();
+    QString app = proc.readLine();
+    app.remove(" ");
+    if (app == "false\n") {
+        ui->appmenu->setChecked(true);
+    } else {
+       ui->appmenu->setChecked(false);
+    }
+    proc.waitForFinished();
+
+    proc.start("gconftool-2 -g /apps/osso/hildon-desktop/key-actions/disable_edit");
+    proc.waitForReadyRead();
+    QString home = proc.readLine();
+    home.remove(" ");
+    if (home == "false\n") {
+        ui->homescreen->setChecked(true);
+    } else {
+       ui->homescreen->setChecked(false);
+    }
+    proc.waitForFinished();
+
+    proc.start("gconftool-2 -g /apps/osso/hildon-status-menu/view/number_of_rows");
+    proc.waitForReadyRead();
+    QString items = proc.readLine();
+    items.remove("\n");
+    int itemsint = items.toInt();
+    ui->items->setValue(itemsint);
+    proc.waitForFinished();
+
+    proc.start("gconftool-2 -g /apps/osso/hildon-status-menu/view/number_of_rows_portrait");
+    proc.waitForReadyRead();
+    items = proc.readLine();
+    items.remove("\n");
+    itemsint = items.toInt();
+    ui->items_portait->setValue(itemsint);
+    proc.waitForFinished();
+
+
     QSettings settings(path, QSettings::IniFormat);
 
     settings.beginGroup("thp_tweaks");
@@ -133,23 +198,16 @@ void mainwindow::readvalues()
 
      settings.beginGroup("launcher_in");
      int speed = settings.value("duration").toInt();
-     if (speed <= 100) {
-         ui->speed->setCurrentIndex(0);
-     } else if (speed >= 101 && speed <= 200) {
-         ui->speed->setCurrentIndex(1);
-     } else if (speed >= 201 && speed <= 300) {
-         ui->speed->setCurrentIndex(2);
-     } else if (speed >= 301 && speed <= 400) {
-         ui->speed->setCurrentIndex(3);
-     } else if (speed >= 401) {
-         ui->speed->setCurrentIndex(4);
-     }
+     ui->speed->setValue(speed);
      settings.endGroup();
 
 }
 
 void mainwindow::storevalues()
 {
+    int speed = ui->speed->value();
+    QString speedstring = QString::number(speed);
+
     QString path2 = "/usr/share/hildon-desktop/transitions.ini";
 
     if (QFile::exists("/etc/hildon/theme/transitions.ini")) {
@@ -157,68 +215,23 @@ void mainwindow::storevalues()
     path2 = "/etc/hildon/theme/transitions.ini";
     system("perl -pi -e \"s/#/;/g\" /etc/hildon/theme/transitions.ini");
 
-    if (ui->speed->currentIndex() == 0) system("perl -pi -e \"s/duration=.*/duration=100/g\" /etc/hildon/theme/transitions.ini");
-    if (ui->speed->currentIndex() == 1) system("perl -pi -e \"s/duration=.*/duration=150/g\" /etc/hildon/theme/transitions.ini");
-    if (ui->speed->currentIndex() == 2) system("perl -pi -e \"s/duration=.*/duration=300/g\" /etc/hildon/theme/transitions.ini");
-    if (ui->speed->currentIndex() == 3) system("perl -pi -e \"s/duration=.*/duration=400/g\" /etc/hildon/theme/transitions.ini");
-    if (ui->speed->currentIndex() == 4) system("perl -pi -e \"s/duration=.*/duration=500/g\" /etc/hildon/theme/transitions.ini");
-
-    if (ui->speed->currentIndex() == 0) system("perl -pi -e \"s/duration_in=.*/duration_in=100/g\" /etc/hildon/theme/transitions.ini");
-    if (ui->speed->currentIndex() == 1) system("perl -pi -e \"s/duration_in=.*/duration_in=150/g\" /etc/hildon/theme/transitions.ini");
-    if (ui->speed->currentIndex() == 2) system("perl -pi -e \"s/duration_in=.*/duration_in=300/g\" /etc/hildon/theme/transitions.ini");
-    if (ui->speed->currentIndex() == 3) system("perl -pi -e \"s/duration_in=.*/duration_in=400/g\" /etc/hildon/theme/transitions.ini");
-    if (ui->speed->currentIndex() == 4) system("perl -pi -e \"s/duration_in=.*/duration_in=500/g\" /etc/hildon/theme/transitions.ini");
-
-    if (ui->speed->currentIndex() == 0) system("perl -pi -e \"s/duration_out=.*/duration_out=100/g\" /etc/hildon/theme/transitions.ini");
-    if (ui->speed->currentIndex() == 1) system("perl -pi -e \"s/duration_out=.*/duration_out=150/g\" /etc/hildon/theme/transitions.ini");
-    if (ui->speed->currentIndex() == 2) system("perl -pi -e \"s/duration_out=.*/duration_out=300/g\" /etc/hildon/theme/transitions.ini");
-    if (ui->speed->currentIndex() == 3) system("perl -pi -e \"s/duration_out=.*/duration_out=400/g\" /etc/hildon/theme/transitions.ini");
-    if (ui->speed->currentIndex() == 4) system("perl -pi -e \"s/duration_out=.*/duration_out=500/g\" /etc/hildon/theme/transitions.ini");
+    sed(speedstring, path2);
 
     }
 
     QString path = "/usr/share/hildon-desktop/transitions.ini";
     system("perl -pi -e \"s/#/;/g\" /usr/share/hildon-desktop/transitions.ini");
-    if (ui->speed->currentIndex() == 0) system("perl -pi -e \"s/duration=.*/duration=100/g\" /usr/share/hildon-desktop/transitions.ini");
-    if (ui->speed->currentIndex() == 1) system("perl -pi -e \"s/duration=.*/duration=150/g\" /usr/share/hildon-desktop/transitions.ini");
-    if (ui->speed->currentIndex() == 2) system("perl -pi -e \"s/duration=.*/duration=300/g\" /usr/share/hildon-desktop/transitions.ini");
-    if (ui->speed->currentIndex() == 3) system("perl -pi -e \"s/duration=.*/duration=400/g\" /usr/share/hildon-desktop/transitions.ini");
-    if (ui->speed->currentIndex() == 4) system("perl -pi -e \"s/duration=.*/duration=500/g\" /usr/share/hildon-desktop/transitions.ini");
 
-    if (ui->speed->currentIndex() == 0) system("perl -pi -e \"s/duration_in=.*/duration_in=100/g\" /usr/share/hildon-desktop/transitions.ini");
-    if (ui->speed->currentIndex() == 1) system("perl -pi -e \"s/duration_in=.*/duration_in=150/g\" /usr/share/hildon-desktop/transitions.ini");
-    if (ui->speed->currentIndex() == 2) system("perl -pi -e \"s/duration_in=.*/duration_in=300/g\" /usr/share/hildon-desktop/transitions.ini");
-    if (ui->speed->currentIndex() == 3) system("perl -pi -e \"s/duration_in=.*/duration_in=400/g\" /usr/share/hildon-desktop/transitions.ini");
-    if (ui->speed->currentIndex() == 4) system("perl -pi -e \"s/duration_in=.*/duration_in=500/g\" /usr/share/hildon-desktop/transitions.ini");
-
-    if (ui->speed->currentIndex() == 0) system("perl -pi -e \"s/duration_out=.*/duration_out=100/g\" /usr/share/hildon-desktop/transitions.ini");
-    if (ui->speed->currentIndex() == 1) system("perl -pi -e \"s/duration_out=.*/duration_out=150/g\" /usr/share/hildon-desktop/transitions.ini");
-    if (ui->speed->currentIndex() == 2) system("perl -pi -e \"s/duration_out=.*/duration_out=300/g\" /usr/share/hildon-desktop/transitions.ini");
-    if (ui->speed->currentIndex() == 3) system("perl -pi -e \"s/duration_out=.*/duration_out=400/g\" /usr/share/hildon-desktop/transitions.ini");
-    if (ui->speed->currentIndex() == 4) system("perl -pi -e \"s/duration_out=.*/duration_out=500/g\" /usr/share/hildon-desktop/transitions.ini");
+    sed(speedstring, path);
 
     QString path3 = "/usr/share/hildon-desktop/transitions.ini";
-    
+
     if (QFile::exists("/opt/theme-customizer/transitions.ini")) {
     path3 = "/opt/theme-customizer/transitions.ini";
     system("perl -pi -e \"s/#/;/g\" /opt/theme-customizer/transitions.ini");
-    if (ui->speed->currentIndex() == 0) system("perl -pi -e \"s/duration=.*/duration=100/g\" /opt/theme-customizer/transitions.ini");
-    if (ui->speed->currentIndex() == 1) system("perl -pi -e \"s/duration=.*/duration=150/g\" /opt/theme-customizer/transitions.ini");
-    if (ui->speed->currentIndex() == 2) system("perl -pi -e \"s/duration=.*/duration=300/g\" /opt/theme-customizer/transitions.ini");
-    if (ui->speed->currentIndex() == 3) system("perl -pi -e \"s/duration=.*/duration=400/g\" /opt/theme-customizer/transitions.ini");
-    if (ui->speed->currentIndex() == 4) system("perl -pi -e \"s/duration=.*/duration=500/g\" /opt/theme-customizer/transitions.ini");
 
-    if (ui->speed->currentIndex() == 0) system("perl -pi -e \"s/duration_in=.*/duration_in=100/g\" /opt/theme-customizer/transitions.ini");
-    if (ui->speed->currentIndex() == 1) system("perl -pi -e \"s/duration_in=.*/duration_in=150/g\" /opt/theme-customizer/transitions.ini");
-    if (ui->speed->currentIndex() == 2) system("perl -pi -e \"s/duration_in=.*/duration_in=300/g\" /opt/theme-customizer/transitions.ini");
-    if (ui->speed->currentIndex() == 3) system("perl -pi -e \"s/duration_in=.*/duration_in=400/g\" /opt/theme-customizer/transitions.ini");
-    if (ui->speed->currentIndex() == 4) system("perl -pi -e \"s/duration_in=.*/duration_in=500/g\" /opt/theme-customizer/transitions.ini");
+    sed(speedstring, path3);
 
-    if (ui->speed->currentIndex() == 0) system("perl -pi -e \"s/duration_out=.*/duration_out=100/g\" /opt/theme-customizer/transitions.ini");
-    if (ui->speed->currentIndex() == 1) system("perl -pi -e \"s/duration_out=.*/duration_out=150/g\" /opt/theme-customizer/transitions.ini");
-    if (ui->speed->currentIndex() == 2) system("perl -pi -e \"s/duration_out=.*/duration_out=300/g\" /opt/theme-customizer/transitions.ini");
-    if (ui->speed->currentIndex() == 3) system("perl -pi -e \"s/duration_out=.*/duration_out=400/g\" /opt/theme-customizer/transitions.ini");
-    if (ui->speed->currentIndex() == 4) system("perl -pi -e \"s/duration_out=.*/duration_out=500/g\" /opt/theme-customizer/transitions.ini");
     }
 
     QSettings settings(path, QSettings::IniFormat);
@@ -244,6 +257,33 @@ void mainwindow::storevalues()
     int radius_moreint = ui->blur->value();
     QString radius_more = QString::number(radius_moreint);
 
+    if ( ui->fm->checkState() == Qt::Checked ) {
+	system("gconftool-2 -s /apps/osso/maemo-statusmenu-fmtx/always_visible -t bool true");
+    } else {
+	system("gconftool-2 -s /apps/osso/maemo-statusmenu-fmtx/always_visible -t bool false");
+    }
+
+    if ( ui->appmenu->checkState() == Qt::Checked ) {
+	system("gconftool-2 -s /apps/osso/hildon-desktop/menu_edit_disabled -t bool false");
+    } else {
+	system("gconftool-2 -s /apps/osso/hildon-desktop/menu_edit_disabled -t bool true");
+    }
+
+    if ( ui->homescreen->checkState() == Qt::Checked ) {
+	system("gconftool-2 -s /apps/osso/hildon-desktop/key-actions/disable_edit -t bool false");
+    } else {
+	system("gconftool-2 -s /apps/osso/hildon-desktop/key-actions/disable_edit -t bool true");
+    }
+
+    QProcess storeproc;
+    QString intvalue = QString::number(ui->items->value());
+    storeproc.start("gconftool-2 -s /apps/osso/hildon-status-menu/view/number_of_rows -t int " + intvalue);
+    storeproc.waitForFinished();
+
+    intvalue = QString::number(ui->items_portait->value());
+    storeproc.start("gconftool-2 -s /apps/osso/hildon-status-menu/view/number_of_rows_portrait -t int " + intvalue);
+    storeproc.waitForFinished();
+
     settings.beginGroup("thp_tweaks");
 
         if ( ui->blurless->checkState() == Qt::Checked ) {
