@@ -9,6 +9,7 @@
 #include <QtCore>
 #include <QMainWindow>
 #include <QLocale>
+#include <QProcess>
 
 namespace Ui {
     class mainwindow;
@@ -23,6 +24,7 @@ public:
     ~mainwindow();
     void readvalues();
     void storevalues();
+    void sed(QString speed, QString path);
     QString abouttext;
     QString abouttitle;
 
